@@ -33,7 +33,7 @@ class _Mask(GeoArray):
     _CLASSNAME = 'Mask baseclass'
 
     def _validate_array_values(self, array):
-        if not array.dtype == np.bool:
+        if not array.dtype == bool:
             if np.issubdtype(array.dtype, np.integer):
                 if array.min() < 0 or array.max() > 1:
                     pixelvals = sorted(list(np.unique(array)))
